@@ -907,7 +907,7 @@
 
 
 /* define with the name of timezone variable */
-#define WX_TIMEZONE timezone
+#define WX_TIMEZONE __timezone
 
 /* The type of 3rd argument to getsockname() - usually size_t or int */
 #define WX_SOCKLEN_T socklen_t
